@@ -9,7 +9,7 @@ spinner = Spinner(
 
 
 def show_selected_value(spinner, text):
-    print('The spinner', spinner, 'have text', text)
+    print('The spinner', spinner, 'has text', text)
 
 
 spinner.bind(text=show_selected_value)
